==> vmngclient-0.18.1.dev0.tar.gz: vmngclient-0.18.1.dev0/vmngclient/endpoints/configuration/policy/list/vpn.py <==
# mypy: disable-error-code="empty-body"


from vmngclient.endpoints import APIEndpoints, delete, get, post, put
from vmngclient.model.policy.lists import VPNList
from vmngclient.model.policy.policy_list import (
    InfoTag,
    PolicyListEndpoints,
    PolicyListId,
    PolicyListInfo,
    PolicyListPreview,
)
from vmngclient.typed_list import DataSequence


class VPNListEditPayload(VPNList, PolicyListId):
    pass


class VPNListInfo(VPNList, PolicyListInfo):
    pass


class ConfigurationPolicyVPNList(APIEndpoints, PolicyListEndpoints):
    @post("/template/policy/list/vpn")
    def create_policy_list(self, payload: VPNList) -> PolicyListId:
        ...

    @delete("/template/policy/list/vpn/{id}")
    def delete_policy_list(self, id: str) -> None:
        ...

    @delete("/template/policy/list/vpn")
    def delete_policy_lists_with_info_tag(self, params: InfoTag) -> None:
        ...

    @put("/template/policy/list/vpn/{id}")
    def edit_policy_list(self, id: str, payload: VPNListEditPayload) -> None:
        ...

    @get("/template/policy/list/vpn/{id}")
    def get_lists_by_id(self, id: str) -> VPNListInfo:
        ...

    @get("/template/policy/list/vpn", "data")
    def get_policy_lists(self) -> DataSequence[VPNListInfo]:
        ...

    @get("/template/policy/list/vpn/filtered", "data")
    def get_policy_lists_with_info_tag(self, params: InfoTag) -> DataSequence[VPNListInfo]:
        ...

    @post("/template/policy/list/vpn/preview")
    def preview_policy_list(self, payload: VPNList) -> PolicyListPreview:
        ...

    @get("/template/policy/list/vpn/preview/{id}")
    def preview_policy_list_by_id(self, id: str) -> PolicyListPreview:
        ...

==> vmngclient-0.22.1.tar.gz: vmngclient-0.22.1/vmngclient/endpoints/configuration/policy/list/vpn.py <==
# mypy: disable-error-code="empty-body"


from uuid import UUID

from vmngclient.endpoints import APIEndpoints, delete, get, post, put
from vmngclient.models.policy.lists import VPNList
from vmngclient.models.policy.policy_list import (
    InfoTag,
    PolicyListEndpoints,
    PolicyListId,
    PolicyListInfo,
    PolicyListPreview,
)
from vmngclient.typed_list import DataSequence


class VPNListEditPayload(VPNList, PolicyListId):
    pass


class VPNListInfo(VPNList, PolicyListInfo):
    pass


class ConfigurationPolicyVPNList(APIEndpoints, PolicyListEndpoints):
    @post("/template/policy/list/vpn")
    def create_policy_list(self, payload: VPNList) -> PolicyListId:
        ...

    @delete("/template/policy/list/vpn/{id}")
    def delete_policy_list(self, id: UUID) -> None:
        ...

    @delete("/template/policy/list/vpn")
    def delete_policy_lists_with_info_tag(self, params: InfoTag) -> None:
        ...

    @put("/template/policy/list/vpn/{id}")
    def edit_policy_list(self, id: UUID, payload: VPNListEditPayload) -> None:
        ...

    @get("/template/policy/list/vpn/{id}")
    def get_lists_by_id(self, id: UUID) -> VPNListInfo:
        ...

    @get("/template/policy/list/vpn", "data")
    def get_policy_lists(self) -> DataSequence[VPNListInfo]:
        ...

    @get("/template/policy/list/vpn/filtered", "data")
    def get_policy_lists_with_info_tag(self, params: InfoTag) -> DataSequence[VPNListInfo]:
        ...

    @post("/template/policy/list/vpn/preview")
    def preview_policy_list(self, payload: VPNList) -> PolicyListPreview:
        ...

    @get("/template/policy/list/vpn/preview/{id}")
    def preview_policy_list_by_id(self, id: UUID) -> PolicyListPreview:
        ...
